[orca] Updating the regression tests for the current unstable OOo (v 3.3).



commit 782cfe461fbf322b4d5b435cf77c82977e5248a9
Author: Joanmarie Diggs <joanmarie diggs gmail com>
Date:   Sat Jul 17 13:44:41 2010 -0400

    Updating the regression tests for the current unstable OOo (v 3.3).

 test/harness/user-settings.py.in                   |    2 +-
 test/harness/utils.py                              |    4 +-
 test/keystrokes/oowriter/bug_364765.py             |    4 +-
 test/keystrokes/oowriter/bug_382408.py             |    4 +-
 test/keystrokes/oowriter/bug_385828.py             |   10 ++--
 test/keystrokes/oowriter/bug_413909.py             |    9 ++--
 test/keystrokes/oowriter/bug_450210.py             |    2 +-
 test/keystrokes/oowriter/bug_546941.py             |   25 +++++++-----
 test/keystrokes/oowriter/table_cells.py            |    4 +-
 .../oowriter/table_cells_structural_navigation1.py |   42 +++++++++++++------
 10 files changed, 67 insertions(+), 39 deletions(-)
---
diff --git a/test/harness/user-settings.py.in b/test/harness/user-settings.py.in
index 3907479..9df938e 100644
--- a/test/harness/user-settings.py.in
+++ b/test/harness/user-settings.py.in
@@ -18,7 +18,7 @@ orca.settings.enableFunctionKeys = False
 orca.settings.enableActionKeys = False
 
 orca.settings.enableBraille = False
-orca.settings.enableBrailleMonitor = False
+orca.settings.enableBrailleMonitor = True
 
 import orca.orca_state
 try:
diff --git a/test/harness/utils.py b/test/harness/utils.py
index dc1bbd1..a13ab0b 100644
--- a/test/harness/utils.py
+++ b/test/harness/utils.py
@@ -38,9 +38,9 @@ firefoxLocationBarNames = "(Location|Search Bookmarks and History)"
 #
 OOoWriterNames = "(StarOffice Writer|OpenOffice.org Writer|OOo-dev Writer Beta)"
 
-OOO_VERSION="Release"
+#OOO_VERSION="Release"
 #OOO_VERSION="Beta"
-#OOO_VERSION="Dev"
+OOO_VERSION="Dev"
 
 def getOOoName(app):
     if OOO_VERSION == "Release":
diff --git a/test/keystrokes/oowriter/bug_364765.py b/test/keystrokes/oowriter/bug_364765.py
index 08a5c10..8d6f48e 100644
--- a/test/keystrokes/oowriter/bug_364765.py
+++ b/test/keystrokes/oowriter/bug_364765.py
@@ -30,7 +30,9 @@ sequence.append(TypeAction("w"))
 sequence.append(WaitForFocus("Letter...", acc_role=pyatspi.ROLE_MENU_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Press W to open the Wizards submenu",
-    ["BRAILLE LINE:  'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane MenuBar File Menu Letter...'",
+    ["BRAILLE LINE:  'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane MenuBar Wizards Menu'",
+     "     VISIBLE:  'Wizards Menu', cursor=1",
+     "BRAILLE LINE:  'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane MenuBar File Menu Letter...'",
      "     VISIBLE:  'Letter...', cursor=1",
      "SPEECH OUTPUT: 'Wizards menu'",
      "SPEECH OUTPUT: 'Letter...'"]))
diff --git a/test/keystrokes/oowriter/bug_382408.py b/test/keystrokes/oowriter/bug_382408.py
index b765cc5..6519aea 100644
--- a/test/keystrokes/oowriter/bug_382408.py
+++ b/test/keystrokes/oowriter/bug_382408.py
@@ -35,7 +35,9 @@ sequence.append(KeyComboAction("Down"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "Type a down arrow to move to the next line",
-    ["BRAILLE LINE:  'This is a test. \$l'",
+    ["BRAILLE LINE:  'soffice Application table-sample.odt - OOo-dev Writer Frame table-sample.odt - OOo-dev Writer RootPane ScrollPane Document view December 2006 \$l'",
+     "     VISIBLE:  'December 2006 $l', cursor=1",
+     "BRAILLE LINE:  'This is a test. \$l'",
      "     VISIBLE:  'This is a test. \$l', cursor=16",
      "BRAILLE LINE:  'This is a test. \$l'",
      "     VISIBLE:  'This is a test. \$l', cursor=16",
diff --git a/test/keystrokes/oowriter/bug_385828.py b/test/keystrokes/oowriter/bug_385828.py
index 5f8e5ef..abf9c57 100644
--- a/test/keystrokes/oowriter/bug_385828.py
+++ b/test/keystrokes/oowriter/bug_385828.py
@@ -36,15 +36,15 @@ sequence.append(WaitForWindowActivate("aw-5blue (read-only) - " + utils.getOOoNa
 sequence.append(WaitForFocus("Page design", acc_role=pyatspi.ROLE_LABEL))
 sequence.append(utils.AssertPresentationAction(
     "Press 'a' to bring up the Agenda... wizard",
-    ["BRAILLE LINE:  " + utils.getOOoName("Writer") + " Frame (1 dialog)'",
+    ["BRAILLE LINE:  " + utils.getOOoBrailleLine("Writer") + " Frame (1 dialog)'",
      "     VISIBLE:  'Frame (1 dialog)', cursor=1",
-     "BRAILLE LINE:  " + utils.getOOoName("Writer") + " Agenda Wizard Dialog'",
+     "BRAILLE LINE:  " + utils.getOOoBrailleLine("Writer") + " Agenda Wizard Dialog'",
      "     VISIBLE:  'Agenda Wizard Dialog', cursor=1",
-     "BRAILLE LINE:  " + utils.getOOoName("Writer") + " Agenda Wizard Dialog Agenda Wizard OptionPane Steps Panel  \$l'",
+     "BRAILLE LINE:  " + utils.getOOoBrailleLine("Writer") + " Agenda Wizard Dialog Agenda Wizard OptionPane Steps Panel  \$l'",
      "     VISIBLE:  ' \$l', cursor=1",
      "SPEECH OUTPUT: 'frame 1 unfocused dialog'",
-     "SPEECH OUTPUT: 'Agenda Wizard Please choose the page design for the agenda 1. Page design 2. General information 3. Headings to include 4. Names 5. Agenda items 6. Name and location'",
-     "SPEECH OUTPUT: 'Page design'"]))
+     "SPEECH OUTPUT: 'Agenda Wizard'",
+     "SPEECH OUTPUT: 'Steps panel'"]))
 
 ######################################################################
 # 5. Press Escape to put focus back in the document.
diff --git a/test/keystrokes/oowriter/bug_413909.py b/test/keystrokes/oowriter/bug_413909.py
index 1c9bc91..436e020 100644
--- a/test/keystrokes/oowriter/bug_413909.py
+++ b/test/keystrokes/oowriter/bug_413909.py
@@ -60,6 +60,7 @@ sequence.append(utils.AssertPresentationAction(
 ######################################################################
 # 5. Enter F7 to bring up the spell checking dialog.
 #
+language = "(English \(USA\)|\[None\])"
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("F7"))
 sequence.append(WaitForFocus("Change", acc_role=pyatspi.ROLE_PUSH_BUTTON))
@@ -95,11 +96,11 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'The quuuiick brown fox $l', cursor=22",
      "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "Untitled[ ]*2", "The quuuiick brown fox \$l") + "'",
      "     VISIBLE:  'The quuuiick brown fox $l', cursor=23",
-     "BRAILLE LINE:  'soffice Application Spell(ing|check): [ \(]*English \(USA\)[\)]* Dialog'",
-     "     VISIBLE:  'Spell(ing|check): [ \(]*English \(USA\)[\)]* Dia(log|)', cursor=1",
-     "BRAILLE LINE:  'soffice Application Spell(ing|check): [ \(]*English \(USA\)[\)]* Dialog Spell(ing|check): [ \(]*English \(USA\)[\)]* OptionPane Change Button'",
+     "BRAILLE LINE:  'soffice Application Spelling: " + language + " Dialog'",
+     "     VISIBLE:  'Spelling: " + language + " Dialog', cursor=1",
+     "BRAILLE LINE:  'soffice Application Spelling: " + language + " Dialog Spelling: " + language + " OptionPane Change Button'",
      "     VISIBLE:  'Change Button', cursor=1",
-     "SPEECH OUTPUT: 'Spell(ing|check): [ \(]*English \(USA\)[\)]*'",
+     "SPEECH OUTPUT: 'Spelling: " + language + "'",
      "SPEECH OUTPUT: 'Misspelled word: quuuiick Context is The quuuiick brown fox'",
      "SPEECH OUTPUT: 'Change button'"]))
 
diff --git a/test/keystrokes/oowriter/bug_450210.py b/test/keystrokes/oowriter/bug_450210.py
index 76aa86e..cf57307 100644
--- a/test/keystrokes/oowriter/bug_450210.py
+++ b/test/keystrokes/oowriter/bug_450210.py
@@ -39,7 +39,7 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'soffice Application Open Dialog Open OptionPane File name:  $l'",
      "     VISIBLE:  'File name:  $l', cursor=12",
      "SPEECH OUTPUT: 'Open'",
-     "SPEECH OUTPUT: 'File name: text '"]))
+     "SPEECH OUTPUT: 'File name: combo box File name: text '"]))
 
 ######################################################################
 # 4. Press Escape to dismiss the Open File Chooser.
diff --git a/test/keystrokes/oowriter/table_cells.py b/test/keystrokes/oowriter/table_cells.py
index 8fac645..9cdd589 100644
--- a/test/keystrokes/oowriter/table_cells.py
+++ b/test/keystrokes/oowriter/table_cells.py
@@ -276,7 +276,9 @@ sequence.append(KeyComboAction("Up"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "Up - Speak Row",
-    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample(.odt|)", "Calendar-1 Table 24 25 26 27 28 29 30") + "'",
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample(.odt|)", "Calendar-1 Table Paragraph") + "'",
+     "     VISIBLE:  'Paragraph', cursor=1",
+     "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample(.odt|)", "Calendar-1 Table 24 25 26 27 28 29 30") + "'",
      "     VISIBLE:  '30', cursor=1",
      "SPEECH OUTPUT: '24 25 26 27 28 29 30'"]))
 
diff --git a/test/keystrokes/oowriter/table_cells_structural_navigation1.py b/test/keystrokes/oowriter/table_cells_structural_navigation1.py
index 3a0538d..29a3e22 100644
--- a/test/keystrokes/oowriter/table_cells_structural_navigation1.py
+++ b/test/keystrokes/oowriter/table_cells_structural_navigation1.py
@@ -82,7 +82,9 @@ sequence.append(KeyComboAction("<Alt><Shift>Left"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "1. Alt Shift Left.",
-    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 3 Paragraph") + "'",
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 4 Paragraph") + "'",
+     "     VISIBLE:  '4 Paragraph', cursor=1",
+     "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 3 Paragraph") + "'",
      "     VISIBLE:  '3 Paragraph', cursor=1",
      "SPEECH OUTPUT: '3'",
      "SPEECH OUTPUT: 'Row 3, column 1.'"]))
@@ -91,14 +93,18 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Left"))
 sequence.append(utils.AssertPresentationAction(
     "2. Alt Shift Left.",
-    ["SPEECH OUTPUT: 'Beginning of row."]))
+    ["BRAILLE LINE:  'Beginning of row.'",
+     "     VISIBLE:  'Beginning of row.', cursor=0",
+     "SPEECH OUTPUT: 'Beginning of row.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Right"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "3. Alt Shift Right.",
-    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 4 Paragraph") + "'",
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 3 Paragraph") + "'",
+     "     VISIBLE:  '3 Paragraph', cursor=1",
+     "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table 4 Paragraph") + "'",
      "     VISIBLE:  '4 Paragraph', cursor=1",
      "SPEECH OUTPUT: '4'",
      "SPEECH OUTPUT: 'Row 3, column 2.'"]))
@@ -149,40 +155,48 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Up"))
 sequence.append(utils.AssertPresentationAction(
     "8. Alt Shift Up.",
-    ["SPEECH OUTPUT: 'Top of column."]))
+    ["BRAILLE LINE:  'Top of column.'",
+     "     VISIBLE:  'Top of column.', cursor=0",
+     "SPEECH OUTPUT: 'Top of column.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>End"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "9. Alt Shift End.",
-    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Paragraph") + "'",
-     "     VISIBLE:  'Paragraph', cursor=1",
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Wed Paragraph") + "'",
+     "     VISIBLE:  'Wed Paragraph', cursor=1",
      "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Paragraph") + "'",
      "     VISIBLE:  'Paragraph', cursor=1",
      "SPEECH OUTPUT: 'blank'",
-     "SPEECH OUTPUT: 'Row 7, column 7.'",
-     "SPEECH OUTPUT: 'End of table blank'",
-     "SPEECH OUTPUT: 'Cell G7'"]))
+     "SPEECH OUTPUT: 'Row 7, column 7.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Down"))
 sequence.append(utils.AssertPresentationAction(
     "10. Alt Shift Down.",
-    ["SPEECH OUTPUT: 'Bottom of column."]))
+    ["BRAILLE LINE:  'Bottom of column.'",
+     "     VISIBLE:  'Bottom of column.', cursor=0",
+     "SPEECH OUTPUT: 'Bottom of column.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Right"))
 sequence.append(utils.AssertPresentationAction(
     "11. Alt Shift Right.",
-    ["SPEECH OUTPUT: 'End of row."]))
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Paragraph") + "'",
+     "     VISIBLE:  'Paragraph', cursor=1",
+     "BRAILLE LINE:  'End of row.'",
+     "     VISIBLE:  'End of row.', cursor=0",
+     "SPEECH OUTPUT: 'End of row.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Home"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 sequence.append(utils.AssertPresentationAction(
     "12. Alt Shift Home.",
-    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Sun Paragraph") + "'",
+    ["BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Paragraph") + "'",
+     "     VISIBLE:  'Paragraph', cursor=1",
+     "BRAILLE LINE:  '" + utils.getOOoBrailleLine("Writer", "table-sample2(.odt|)", "Calendar-1 Table Sun Paragraph") + "'",
      "     VISIBLE:  'Sun Paragraph', cursor=1",
      "SPEECH OUTPUT: 'Sun'",
      "SPEECH OUTPUT: 'Row 1, column 1.'"]))
@@ -191,7 +205,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt><Shift>Up"))
 sequence.append(utils.AssertPresentationAction(
     "13. Alt Shift Up.",
-    ["SPEECH OUTPUT: 'Top of column."]))
+    ["BRAILLE LINE:  'Top of column.'",
+     "     VISIBLE:  'Top of column.', cursor=0",
+     "SPEECH OUTPUT: 'Top of column.'"]))
 
 ######################################################################
 # Enter Alt-f, Alt-c to close this Writer application.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/test/keystrokes/oowriter/bug_546941.py b/test/keystrokes/oowriter/bug_546941.py
index 5690fd8..5af40a0 100644
--- a/test/keystrokes/oowriter/bug_546941.py
+++ b/test/keystrokes/oowriter/bug_546941.py
@@ -47,27 +47,32 @@ sequence.append(KeyComboAction("<Alt>o"))
 sequence.append(WaitForFocus("Default Formatting", acc_role=pyatspi.ROLE_MENU_ITEM))
 
 ######################################################################
-# 6. Press "h" to select "Character".
+# 6. Press "h" to select "Character". Then Control Page Down to move to
+# Font Effects.
 #
 sequence.append(TypeAction("h"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST))
+sequence.append(WaitForWindowActivate("Character", None))
+sequence.append(KeyComboAction("<Control>Page_Down"))
 
 ######################################################################
 # 7. Press Tab to move to move to Strikethrough.
 #
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Tab"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST))
+sequence.append(KeyComboAction("<Alt>s"))
 sequence.append(utils.AssertPresentationAction(
     "Move to Strikethrough",
-    ["BRAILLE LINE:  'soffice Application Character Dialog Character OptionPane TabList Font Effects Page Strikethrough (Without) Combo'",
-     "     VISIBLE:  '(Without) Combo', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Strikethrough (Without) combo box'"]))
+    ["BUG? - Some panel is claiming focus and needs to be ignored.",
+     "BRAILLE LINE:  'soffice Application Character Dialog Character OptionPane TabList Font Effects Page Strikethrough (Without) Combo'",
+     "     VISIBLE:  'Strikethrough (Without) Combo', cursor=15",
+     "BRAILLE LINE:  'soffice Application Character Dialog Character OptionPane TabList Font Effects Page Strikethrough Panel'",
+     "     VISIBLE:  'Strikethrough Panel', cursor=1",
+     "SPEECH OUTPUT: 'Strikethrough (Without) combo box'",
+     "SPEECH OUTPUT: 'Font Effects page Strikethrough combo box Strikethrough panel'",]))
 
 ######################################################################
-# 8. Press Escape to exit the dialog.
+# 8. Put things back to the way the were and exit the dialog.
 #
+sequence.append(KeyComboAction("<Control>Page_Up"))
 sequence.append(KeyComboAction("Escape"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
 
@@ -47,27 +47,32 @@ sequence.append(KeyComboAction("<Alt>o"))
 
 ######################################################################
-# 7. Press Tab to move to move to Strikethrough.
+# 7. Press Alt+S to move to move to Strikethrough.
 #
 sequence.append(utils.StartRecordingAction())